@@ -43,7 +43,7 @@ class Client(object):
 
         # Process domain, strip subdomain
         domain_extractor = tldextract.TLDExtract(
-            cache_file=TLDEXTRACT_CACHE_FILE, include_psl_private_domains=True
+            include_psl_private_domains=True
         )
         domain_parts = domain_extractor(self.config.resolve("lexicon:domain"))
         runtime_config["domain"] = "{0}.{1}".format(
