@@ -1,2 +1,2 @@
 """General configuration of lexicon.providers package"""
-__author__ = 'Jason Kulatunga'
+__author__ = "Jason Kulatunga"
