@@ -94,15 +94,13 @@ class Provider(BaseProvider):
         ttl = self._get_lexicon_option("ttl")
 
         # Retrieve existing data in DNS zone.
-        records = self._get("/domains/{0}/records".format(domain))
+        records = self._get(
+            "/domains/{0}/records/{1}/{2}".format(domain, rtype, relative_name)
+        )
 
         # Check if a record already matches given parameters
         for record in records:
-            if (
-                record["type"] == rtype
-                and self._relative_name(record["name"]) == relative_name
-                and record["data"] == content
-            ):
+            if record["data"] == content:
                 LOGGER.debug(
                     "create_record (ignored, duplicate): %s %s %s", rtype, name, content
                 )
@@ -115,8 +113,10 @@ class Provider(BaseProvider):
 
         records.append(data)
 
-        # Synchronize data with inserted record into DNS zone.
-        self._put("/domains/{0}/records".format(domain), records)
+        # Insert the record
+        self._put(
+            "/domains/{0}/records/{1}/{2}".format(domain, rtype, relative_name), records
+        )
 
         LOGGER.debug("create_record: %s %s %s", rtype, name, content)
 
@@ -142,6 +142,7 @@ class Provider(BaseProvider):
         if name:
             relative_name = self._relative_name(name)
 
+        updated_record = None
         # Retrieve existing data in DNS zone.
         records = self._get("/domains/{0}/records".format(domain))
 
@@ -157,10 +158,21 @@ class Provider(BaseProvider):
                 and record["data"] != content
             ):
                 record["data"] = content
+                updated_record = record
                 break
 
         # Synchronize data with updated records into DNS zone.
-        self._put("/domains/{0}/records".format(domain), records)
+        if updated_record is not None:
+            if (
+                identifier
+                and self._relative_name(updated_record["name"]) != relative_name
+            ):
+                self._put("/domains/{0}/records/{1}".format(domain, rtype), records)
+            else:
+                self._put(
+                    "/domains/{0}/records/{1}/{2}".format(domain, rtype, relative_name),
+                    updated_record,
+                )
 
         LOGGER.debug("update_record: %s %s %s", rtype, name, content)
 
