@@ -6,14 +6,15 @@ from lexicon.tests.providers.integration_tests import IntegrationTestsV2
 
 class EasynameProviderTests(TestCase, IntegrationTestsV2):
     """TestCase for EasyName"""
-    provider_name = 'easyname'
-    domain = 'lexicontest.astzweig.de'
+
+    provider_name = "easyname"
+    domain = "nigl.it"
 
     def _filter_post_data_parameters(self):
-        return ['username', 'password']
+        return ["username", "password"]
 
     def _filter_headers(self):
-        return ['Cookie']
+        return ["Cookie"]
 
     def _test_fallback_fn(self):
-        return lambda x: 'placeholder_' + x if x != 'priority' else ''
+        return lambda x: "placeholder_" + x if x != "priority" else ""
